@@ -1,5 +1,5 @@
 #
-# $Id: Pivots.pm,v cfbea05b0bc4 2025/01/28 15:06:19 gomor $
+# $Id: Pivots.pm,v 58d7ce835577 2023/03/25 10:34:10 gomor $
 #
 package OPP::Proc::Pivots;
 use strict;
@@ -24,7 +24,7 @@ sub process {
       domain organization geolocus.netname netname subject.organization
       subject.email issuer.organization
       app.http.tracker.ga app.http.tracker.gaw app.http.tracker.gpub
-      app.http.tracker.fbq app.http.tracker.snaptr app.http.tracker.newrelic
+      app.http.tracker.fbq app.http.tracker.snaptr
    ) ];
 
    my $rewrite = {
@@ -64,7 +64,7 @@ OPP::Proc::Pivots - pivots processor
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2025, ONYPHE SAS
+Copyright (c) 2023, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
